simdurbin2
dhhrcomp(nsims = 1024, nmu = 4,
mu0 = c(0, 5, 10, 15, 20, 25, 30, 40, 50, 60,
65, 70, 80, 100, 200, 300, 500, 1000) * 1000)nmu genes from mu for usenmu of the mean intensities considerednmu variances, one for each mean in
mu0.
The variance is the variance of the DDHFm transformed simulated
intensity data.nmu skewnesses, one for each mean in
mu0.
The skewness is the skewness of the DDHFm transformed simulated
intensity data.nmu kurtoses, one for each mean in
mu0.
The kurtosis is the kurtosis of the DDHFm transformed simulated
intensity data.mu0.
The first nmu of these are selected. Then for each
of the selected means nsims gene intensities are
generated.The intensities are them subjected to DDHF transformation.
simdurbin2