Learn R Programming

DDHFm (version 1.1.4)

dhhrss: Tabulates variance, skewness and kurtosis coefficients from the output of dhhrcomp

Description

Tabulates the variance, skewness and kurtosis coefficients from the output of dhhrcomp

Usage

dhhrss(dhhrobj)

Value

None, prints a table.

Arguments

dhhrobj

The results to be tabulated. The output of a call to dhhrcomp

Author

Guy Nason <[email protected].

Details

This routine merely runs summary statistics calculations on the output results from dhhrcomp